@@ -9,7 +9,6 @@ import sys
 from cliff.command import Command
 from nilm.meter import meter
 from nilm.meter.utils import MeterConfigurationError
-from joule.utils.nilmdb import Client
 
 ESC_SEQ = "\x1b["
 COL_RESET = ESC_SEQ+"0m"
@@ -74,30 +73,18 @@ class ConfigureCmd(Command):
         for my_meter in meters.values():
             if(my_meter['enabled']):
                 print(my_meter['name']+":")
-                self._build_info_stream(my_meter, parsed_args.nilmdb_url)
                 self._build_module_configs(my_meter, parsed_args.legacy)
                 self._build_stream_configs(my_meter, parsed_args.legacy)
             else:
                 print(my_meter['name']+": (disabled)")
                 self._remove_modules(my_meter)
-
-    def _build_info_stream(self, my_meter, nilmdb_url):
-        my_client = Client(nilmdb_url)
-        # check if an info stream exists
-        info_path = "%s/info" % my_meter['path']
-        sys.stdout.write("\tbuilding info stream ")
-        if(my_client.stream_info(info_path) is None):
-            my_client.stream_create(info_path, "uint8_1")
-            print("["+COL_GREEN+"OK"+COL_RESET+"]")
-        else:
-            print("["+COL_GREEN+"EXISTS"+COL_RESET+"]")
             
     def _build_module_configs(self, my_meter, legacy):
         sys.stdout.write("\tgenerating module configuration ")
 
         path = my_meter['path']
         sensor_path = "%s/sensor" % path
-        iv_path = "%s/iv" % path
+        iv_path = "%s/IV" % path
         sf_path = "%s/sinefit" % path
         prep_path = "%s/prep" % path
 
@@ -151,7 +138,7 @@ class ConfigureCmd(Command):
         process_config['Outputs'] = {"iv": iv_path,
                                      "zero_crossings": sf_path}
 
-        if(legacy):
+        if legacy:
             for n in range(my_meter['phases']):
                 ph = 'abc'[n]
                 stream = "%s-%c" % (prep_path, ph)
@@ -175,11 +162,11 @@ class ConfigureCmd(Command):
         else:  # contact meter
             dtype = "uint16"
         sensor_config = configparser.ConfigParser()
-        sensor_config['Main'] = {"name": "sensors",
+        sensor_config['Main'] = {"name": "sensor",
                                  "datatype": dtype,
                                  "keep": settings["keep"],
                                  "decimate": settings["decimate"],
-                                 "path": "%s/sensor" % path}
+                                 "path": path}
         if(my_meter['type'] == "noncontact"):
             num_channels = 8
         else:  # contact
@@ -194,11 +181,11 @@ class ConfigureCmd(Command):
         # --iv stream--
         settings = my_meter["streams"]["iv"]
         iv_config = configparser.ConfigParser()
-        iv_config['Main'] = {"name": "I/V",
+        iv_config['Main'] = {"name": "IV",
                              "datatype": "float32",
                              "keep": settings["keep"],
                              "decimate": settings["decimate"],
-                             "path": "%s/iv" % path}
+                             "path": path}
         i = 1
         if(my_meter["type"] == "noncontact"):
             iv_config['Element1'] = {"name": "Voltage",
@@ -228,7 +215,7 @@ class ConfigureCmd(Command):
                              "datatype": "float32",
                              "keep": settings["keep"],
                              "decimate": settings["decimate"],
-                             "path": "%s/sinefit" % path}
+                             "path": path}
         sf_config['Element1'] = {"name": "Frequency",
                                  "units": "Hz",
                                  "discrete": "yes"}
@@ -259,7 +246,7 @@ class ConfigureCmd(Command):
                                "datatype": "float32",
                                "keep": settings["keep"],
                                "decimate": settings["decimate"],
-                               "path": "%s/prep" % path}
+                               "path": path}
         i = 1
         for ph in range(my_meter["phases"]):
             ph_name = ['A', 'B', 'C'][ph]
@@ -287,7 +274,7 @@ class ConfigureCmd(Command):
                                    "datatype": "float32",
                                    "keep": settings["keep"],
                                    "decimate": settings["decimate"],
-                                   "path": "%s/prep-%c" % (path, ph)}
+                                   "path": path}
             i = 1
             for harm in [1, 3, 5, 7]:
                 prep_config['Element%d' % i] = {"name": "P%d" % harm,
