@@ -6,6 +6,7 @@ from joule import FilterModule, utilities
 import scipy.fftpack  # fftpack fft??
 import asyncio
 from . import helpers
+from joule.models.pipes import EmptyPipe
 
 ARGS_DESC = """
 ---
@@ -218,8 +219,12 @@ class Prep(FilterModule):
             raise helpers.FilterError("required inputs [iv, zero_crossings], outputs [prep] (or [prep-a,...])")
 
         while True:
-            iv_data = await iv.read(flatten=True)
-            zc_data = await zc.read(flatten=True)
+            try:
+                iv_data = await iv.read(flatten=True)
+                zc_data = await zc.read(flatten=True)
+            except EmptyPipe:
+                break
+
             # print("iv [%d]  %s->%s" % (len(iv_data), timestamp_to_human(iv_data[0, 0]),
             #                           timestamp_to_human(iv_data[-1, 0])))
             # print("zc [%d] %s->%s" % (len(zc_data), timestamp_to_human(zc_data[0, 0]),
