@@ -127,7 +127,10 @@ def check_syntax(name, config):
                                 "repeats are not allowed")
                     return Status.error
                 # 5b1 make sure there are enough current sensors
-                if(phases > len(x)):
+                effective_phases = phases
+                if(config["calibration"]["has_neutral"] is False):
+                    effective_phases -= 1
+                if(effective_phases > len(x)):
                     print_error(
                         "%s number of current sensors must be greater than or equal to phases" % name)
                     return Status.error
